 <?php
require_once("../../../class/class.conectar.php");
require_once("../../../class/class.usudep.php");
require_once("../../../class/class.vacaciones.php");


$Objcon = new Conectar();
$conex = $Objcon->con();

$ugid=$_GET['ugid'];

if(isset($_GET['tvaca'])){
    $tvaca=$_GET['tvaca'];
  }else{
    $tvaca=0;
}
date_default_timezone_set("America/Lima"); setlocale(LC_TIME,"es_PE.UTF-8");

function validar_registrar_vaca($ugid, $fechaini,$fechafin,$periodo,$numdias){
  //buscando si existe interseccion fechas con dias registrados
  $Objvpp1 = new Vacaciones(); $Objvpp2 = new Vacaciones();
  $res_vp1 = array(); $res_vp2 = array();
  $res_vp1 = $Objvpp1->consultar_vacaciones_programadas_personal($conex,$ugid, $fechaini);
  $res_vp2 = $Objvpp2->consultar_vacaciones_programadas_personal($conex,$ugid, $fechafin);

    //consulta de los numero de dias programados en las vacaciones
    $Objvp = new Vacaciones();
    $res_vp = array();
    $res_vp=$Objvp->aks_vacaciones($conex,$ugid,$periodo,0);
    $numdias1 = $res_vp[0]['suma'];
    $T_vac1=$res_vp[0]['numdias'];

    //consulta de los numero de dias ejecutados en las vacaciones
    $Objve = new Vacaciones();
    $res_ve = array();
    $res_ve=$Objve->aks_vacaciones($conex,$ugid,$periodo,1);
    $numdias2 = $res_ve[0]['suma'];
    $T_vac2=$res_ve[0]['numdias'];

  $numdiasT = $numdias1 + $numdias2;
  $numdiasT_T = $numdiasT + $numdias;

  if($numdiasT_T >0 && $numdiasT_T < 31){
    if((count($res_vp1)==0) && (count($res_vp2)==0)){
            $id_vp1 = $Objvpp1->buscar_id_vacac($conex,$ugid);
                if($id_vp1==0){
                $numid = 1;
                }else{
                $numid = $id_vp1+1;
                }
            $Objvpp1->insert_vaca_prog($conex,$numid,$ugid,$periodo,$fechaini,$fechafin,$numdias);
            $error=0;
            echo "<script type='text/javascript'>window.opener.location.reload(); window.close();</script>";
        }else{
            $error = 1;
            echo "<script type='text/javascript'>alert('EXISTE CRUCE DE FECHAS');return;</script>";
        }
    }else{
        $error=2;
        echo "<script type='text/javascript'>alert('SE EXCEDE MAS DE 30 DIAS');return;</script>";
    }
}


if($tvaca == 1){
  $periodo=$_GET['periodo'];
  $ugid = $_GET['ugid'];
  $fanno = $_GET['fanno'];
  $fmes = $_GET['fmes'];
  $fechainia = "01/".$fmes."/".$fanno;
  $fechafin = date("d-m-Y",strtotime($fini."+ 29 days"));
  $diaini=substr($fechainia, 0, 2);
  $diafin=substr($fechafina, 0, 2);
  $mesini=substr($fechainia, 3, 2);
  $mesfin=substr($fechafina, 3, 2);
  $annoini=substr($fechainia, 6, 4);
  $annofin=substr($fechafina, 6, 4);
  $fechaini =$annoini.'/'.$mesini.'/'.$diaini;
  $fechafin =$annofin.'/'.$mesfin.'/'.$diafin;
  $numdias = 30;
  validar_registrar_vaca($ugid, $fechaini,$fechafin,$periodo,$numdias);
}

if($tvaca == 2){
    if(isset($_GET['fechaini']) && $_GET['fechaini']!=''){
    $fechainia=$_GET['fechaini'];
    $fechafina=$_GET['fechafin'];
    $periodo=$_GET['periodo'];
    $ugid = $_GET['ugid'];
    $diaini=substr($fechainia, 0, 2);
    $diafin=substr($fechafina, 0, 2);
    $mesini=substr($fechainia, 3, 2);
    $mesfin=substr($fechafina, 3, 2);
    $annoini=substr($fechainia, 6, 4);
    $annofin=substr($fechafina, 6, 4);
    $fechaini =$annoini.'/'.$mesini.'/'.$diaini;
    $fechafin =$annofin.'/'.$mesfin.'/'.$diafin;
    $numdias=restaFechas($fechainia,$fechafina);
    $numdias=$numdias+1;
    if(($diaini<=$diafin && $mesini==$mesfin && $annoini<=$annofin) || ($mesini<$mesfin && $annoini<=$annofin) || ($annoini<$annofin)){
      validar_registrar_vaca($ugid, $fechaini,$fechafin,$periodo,$numdias);
      }else{
      $error=3;
      echo "<script type='text/javascript'>alert('REVISAR LAS FECHAS INGRESADAS');return;</script>";
      }
    }
}
//restando fechas
function restaFechas($dFecIni, $dFecFin)
{
    $dFecIni = str_replace("-","",$dFecIni);
    $dFecIni = str_replace("/","",$dFecIni);
    $dFecFin = str_replace("-","",$dFecFin);
    $dFecFin = str_replace("/","",$dFecFin);

	//preg_match() ->que busca en una determinada cadena alguna coincidencia usando una expresión regular
    preg_match( "([0-9]{1,2})([0-9]{1,2})([0-9]{2,4})", $dFecIni, $aFecIni);
    preg_match( "([0-9]{1,2})([0-9]{1,2})([0-9]{2,4})", $dFecFin, $aFecFin);

    $date1 = mktime(0,0,0,$aFecIni[2], $aFecIni[1], $aFecIni[3]);
    $date2 = mktime(0,0,0,$aFecFin[2], $aFecFin[1], $aFecFin[3]);

    return round(($date2 - $date1) / (60 * 60 * 24));
}

//seleccionando al personal
$Objp = new UsuarioDependencia();
$res_p = array();
$res_p = $Objp->buscar_cod_per($conex,$ugid);
$nombre = $res_p[0]['nombre'];
$fechaing = $res_p[0]['fingreso'];

?>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
<title>VACACIONES PROGRAMADAS DEL PERSONAL ASISTENCIAL</title>


<script language="JavaScript" type="text/javascript" src="ajax.js"></script>

<link rel="stylesheet" type="text/css" href="../styles/Style.css">
<link type="text/css" rel="stylesheet" href="src/css/jscal2.css" />
 <link type="text/css" rel="stylesheet" href="src/css/border-radius.css" />
 <link id="skin-gold" title="Gold" type="text/css" href="src/css/gold/gold.css" />
 <script src="src/js/jscal2.js"></script>
 <script src="src/js/lang/es.js"></script>

<script type="text/javascript">

function ventanaClose(){
   //alert("hola mundo");
    window.close();
}

function gragarVAC(){
	var ugid = document.getElementById('ugid').value;
	var f_ini = document.getElementById('fechaini').value;
	var f_fin = document.getElementById('fechafin').value;
	var periodo = document.getElementById('anno').value;
	if(f_ini != '' && f_fin != ''){
	d_ini=f_ini.substring(0,2);
	m_ini=f_ini.substring(3,5);
	a_ini=f_ini.substring(6,10);
	var F_ini = new Date(a_ini+"/"+m_ini+"/"+d_ini);

	d_fin=f_fin.substring(0,2);
	m_fin=f_fin.substring(3,5);
	a_fin=f_fin.substring(6,10);
	var F_fin = new Date(a_fin+"/"+m_fin+"/"+d_fin);
	resFechas = F_fin - F_ini;
	resFechas=((((resFechas/1000)/60)/60)/24) + 1;
			if(resFechas<31 && resFechas>6){
			window.location ="vacacionesprog.php?ugid="+ugid+"&fechaini="+f_ini+"&fechafin="+f_fin+"&periodo="+periodo;
			}else{
			 alert("Verifique las Fechas");
			}
	}else{
		if(f_ini==''){
			alert("Ingrese la fecha Inicial");
		}
		if(f_fin==''){
			alert("Ingrese la fecha Final");
		}
	}
}
</script>
</head>
<body>
<table align='center'>
<tr><td>
<div id='transfpersonal'>

<?php
//<form action='vacacionesprog.php' >
echo "<input type='hidden' id='ugid' name='ugid' value='".$ugid."'>";
?>
<fieldset>
	<legend align='left'><font color='blue' size='15'>Escriba la Fecha de las Vacaciones </font></legend>
	<br>
		<table align='center' class='FacetFormTABLE' width='450'>
		<tr><td class='FacetFieldCaptionTDT' colspan='4'><center>VACACIONES PROGRAMADAS DEL PERSONAL ASISTENCIAL</center></td></tr>
		<tr><td colspan='4'><center><?php if(isset($error)){if($error=='1'){ echo "REVISE LOS DATOS, PERSONAL NO REGISTRADO";}elseif($error=='0'){ echo "PERSONAL REGISTRADO";}}?></center></td></tr>
		<tr><td align='right' class='FacetFieldCaptionTD' style='width:300px'>PERSONAL </td><td colspan='3'><?php echo $nombre; ?></td></tr>
		<tr><td align='right' class='FacetFieldCaptionTD' style='width:300px'>FECHA INGRESO </td><td colspan='3'><?php echo $fechaing; ?></td></tr>
		<tr><td align='right' class='FacetFieldCaptionTD' style='width:300px'>PERIODO </td><td colspan='3'>
		<?php
		echo "<select name='anno' id='anno'>";
		for ($i=2000;$i<2100;$i++){
		echo "<option value='".$i."'";
		if(date("Y",time())==$i){?> selected
		<?php
		$anno=$i;
		} echo ">".$i."</option>";
		}
		echo "</select>";
		?></td></tr>
		<tr><td align='right' class='FacetFieldCaptionTD'>FECHA INICIAL</td>
		<td>
		<input type='text' id='fechaini' name='fechaini' size='15' value=<?php if(isset($error)){if($error==2){ echo $fechainia;} }?> >
		<button id="calendar-trigger1"><img src="../../img/b_calendar.png" ></button>
                <button id="f_clearRangeStart1" onclick="clearRangeStart1()">clear</button>
                <script>
					Calendar.setup({
						trigger    : "calendar-trigger1",
						inputField : "fechaini",
						dateFormat : "%d/%m/%Y",
						onSelect   : function() { this.hide() }

					});

					 function clearRangeStart1() {
						 document.getElementById("fechaini").value = "";                          };
                </script>
		</td>
		<td align='right' class='FacetFieldCaptionTD'>FECHA FINAL</td>
		<td>
		<input type='text' id='fechafin' name='fechafin' size='15' value=<?php if(isset($error)){if($error==2){ echo $fechafina;}} ?>>
		<button id="calendar-trigger2"><img src="../../img/b_calendar.png" ></button>
		 <button id="f_clearRangeStart2" onclick="clearRangeStart2()">clear</button>
             <script>
					Calendar.setup({
						trigger    : "calendar-trigger2",
						inputField : "fechafin",
						dateFormat : "%d/%m/%Y",
						onSelect   : function() { this.hide() }

					});

					 function clearRangeStart2() {
						 document.getElementById("fechafin").value = "";                          };
                </script>
		</td>
		</tr>

		<tr><td align='center' colspan='4'><button type='button' style='width:150px' class='FacetButton'  onClick='gragarVAC()'>Grabar</button>
		<button type='button' style='width:150px' class='FacetButton' onClick='ventanaClose();' >Cancelar</button>
		</td></tr></table>
	  <br>
	</fieldset>
</div>
</td><tr>
</table>
</body>
</html>
